pub enum EllipsizeHeightLimit {
Lines(usize),
Height(f32),
}Variants
Lines(usize)
Number of lines to show before ellipsizing the rest. Only works if Wrap is NOT set to
Wrap::None. Otherwise, it will be ignored and the behavior will be the same as Lines(1)
Height(f32)
Ellipsizes the last line that fits within the given height limit. If Wrap is set to
Wrap::None, the behavior will be the same as Lines(1)